==> hornsey_1.0~20090727.orig.tar.gz: hornsey-1.0~20090727/src/hrn-sidebar-subitem.h <==
#ifndef __HRN_SIDEBAR_SUBITEM_H__
#define __HRN_SIDEBAR_SUBITEM_H__

#include <nbtk/nbtk.h>
#include "hrn-source.h"

G_BEGIN_DECLS

#define HRN_TYPE_SIDEBAR_SUBITEM                                        \
  (hrn_sidebar_subitem_get_type ())
#define HRN_SIDEBAR_SUBITEM(obj)                                        \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj),                                  \
                               HRN_TYPE_SIDEBAR_SUBITEM,               \
                               HrnSidebarSubitem))
#define HRN_SIDEBAR_SUBITEM_CLASS(klass)                                \
  (G_TYPE_CHECK_CLASS_CAST ((klass),                                   \
                            HRN_TYPE_SIDEBAR_SUBITEM,                  \
                            HrnSidebarSubitemClass))
#define IS_HRN_SIDEBAR_SUBITEM(obj)                                     \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj),                                  \
                               HRN_TYPE_SIDEBAR_SUBITEM))
#define IS_HRN_SIDEBAR_SUBITEM_CLASS(klass)                             \
  (G_TYPE_CHECK_CLASS_TYPE ((klass),                                   \
                            HRN_TYPE_SIDEBAR_SUBITEM))
#define HRN_SIDEBAR_SUBITEM_GET_CLASS(obj)                              \
  (G_TYPE_INSTANCE_GET_CLASS ((obj),                                   \
                              HRN_TYPE_SIDEBAR_SUBITEM,                \
                              HrnSidebarSubitemClass))

typedef struct _HrnSidebarSubitemPrivate HrnSidebarSubitemPrivate;
typedef struct _HrnSidebarSubitem HrnSidebarSubitem;
typedef struct _HrnSidebarSubitemClass HrnSidebarSubitemClass;

struct _HrnSidebarSubitem
{
  NbtkButton parent;

  HrnSidebarSubitemPrivate *priv;
};

struct _HrnSidebarSubitemClass
{
  NbtkButtonClass parent_class;
};

GType              hrn_sidebar_subitem_get_type (void) G_GNUC_CONST;
HrnSidebarSubitem *hrn_sidebar_subitem_new (HrnSource  *source,
                                            const char *qname,
                                            const char *title,
                                            const char *iconname,
                                            gboolean    show_pin,
                                            gboolean    can_rename);
const char *hrn_sidebar_subitem_get_title (HrnSidebarSubitem *item);
const char *hrn_sidebar_subitem_get_qname (HrnSidebarSubitem *item);


G_END_DECLS

#endif /* __HRN_SIDEBAR_SUBITEM_H__ */

==> hornsey_1.5.1.orig.tar.gz: hornsey-1.5.1/src/hrn-sidebar-subitem.h <==
#ifndef __HRN_SIDEBAR_SUBITEM_H__
#define __HRN_SIDEBAR_SUBITEM_H__

#include <nbtk/nbtk.h>

G_BEGIN_DECLS

#define HRN_TYPE_SIDEBAR_SUBITEM                                        \
  (hrn_sidebar_subitem_get_type ())
#define HRN_SIDEBAR_SUBITEM(obj)                                        \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj),                                  \
                               HRN_TYPE_SIDEBAR_SUBITEM,               \
                               HrnSidebarSubitem))
#define HRN_SIDEBAR_SUBITEM_CLASS(klass)                                \
  (G_TYPE_CHECK_CLASS_CAST ((klass),                                   \
                            HRN_TYPE_SIDEBAR_SUBITEM,                  \
                            HrnSidebarSubitemClass))
#define IS_HRN_SIDEBAR_SUBITEM(obj)                                     \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj),                                  \
                               HRN_TYPE_SIDEBAR_SUBITEM))
#define IS_HRN_SIDEBAR_SUBITEM_CLASS(klass)                             \
  (G_TYPE_CHECK_CLASS_TYPE ((klass),                                   \
                            HRN_TYPE_SIDEBAR_SUBITEM))
#define HRN_SIDEBAR_SUBITEM_GET_CLASS(obj)                              \
  (G_TYPE_INSTANCE_GET_CLASS ((obj),                                   \
                              HRN_TYPE_SIDEBAR_SUBITEM,                \
                              HrnSidebarSubitemClass))

typedef struct _HrnSidebarSubitemPrivate HrnSidebarSubitemPrivate;
typedef struct _HrnSidebarSubitem HrnSidebarSubitem;
typedef struct _HrnSidebarSubitemClass HrnSidebarSubitemClass;

struct _HrnSidebarSubitem
{
  NbtkButton parent;

  HrnSidebarSubitemPrivate *priv;
};

struct _HrnSidebarSubitemClass
{
  NbtkButtonClass parent_class;
};

GType              hrn_sidebar_subitem_get_type (void) G_GNUC_CONST;
HrnSidebarSubitem *hrn_sidebar_subitem_new (const char *qname,
                                            const char *title,
                                            const char *iconname,
                                            gboolean    show_pin,
                                            gboolean    can_rename);
const char *hrn_sidebar_subitem_get_title (HrnSidebarSubitem *item);
const char *hrn_sidebar_subitem_get_qname (HrnSidebarSubitem *item);

G_END_DECLS

#endif /* __HRN_SIDEBAR_SUBITEM_H__ */
